##
##  php-memcached.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_memcache           3.0.8
%define       V_memcached          3.2.0

#   package information
Name:         php-memcached
Summary:      PHP Memcached API
URL:          http://memcached.org/
Vendor:       The PHP Group
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Language
License:      PHP
Version:      20160307
Release:      20231228

#   package options
%option       with_apache  no

#   list of sources
Source0:      http://pecl.php.net/get/memcache-%{V_memcache}.tgz
Source1:      http://pecl.php.net/get/memcached-%{V_memcached}.tgz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, libtool, autoconf, automake
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  php, php::with_session = yes, php::with_zlib = yes
PreReq:       php, php::with_session = yes, php::with_zlib = yes
BuildPreReq:  memcached
PreReq:       memcached
%if "%{with_apache}" == "yes"
PreReq:       apache, apache-php, apache-php::with_session = yes, apache-php::with_zlib = yes
%endif

%description
    These are Memcached client APIs for PHP.

%track
    prog php-memcached:memcache = {
        version   = %{V_memcache}
        url       = http://pecl.php.net/package/memcache
        regex     = memcache-(__VER__)\.tgz
    }
    prog php-memcached:memcached = {
        version   = %{V_memcached}
        url       = http://pecl.php.net/package/memcached
        regex     = memcached-(\d+\.\d+\.\d+)\.tgz
    }

%prep
    %setup -q -c
    %setup -q -T -D -a 1

%build
    #   build PHP Memcached API 1/2
    ( cd memcache-%{V_memcache}
      %{l_prefix}/bin/phpize
      CC="%{l_cc}" \
      CFLAGS="%{l_cflags -O}" \
      CPPFLAGS="%{l_cppflags}" \
      LDFLAGS="%{l_ldflags}" \
      LIBS="-lssl -lcrypto" \
      GREP="grep" \
      ./configure \
          --prefix=%{l_prefix} \
          --with-php-config=%{l_prefix}/bin/php-config \
          --enable-shared \
          --disable-static
      %{l_make} %{l_mflags -O}
    ) || exit $?

    #   build PHP Memcached API 2/2
    ( cd memcached-%{V_memcached}
      %{l_prefix}/bin/phpize
      CC="%{l_cc}" \
      CFLAGS="%{l_cflags -O}" \
      CPPFLAGS="%{l_cppflags}" \
      LDFLAGS="%{l_ldflags}" \
      LIBS="-lssl -lcrypto" \
      GREP="grep" \
      ./configure \
          --prefix=%{l_prefix} \
          --with-php-config=%{l_prefix}/bin/php-config \
          --with-libmemcached-dir=%{l_prefix} \
          --enable-shared \
          --disable-static
      %{l_make} %{l_mflags -O}
    ) || exit $?

%install
    #   create installation hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/php-memcached

    #   install PHP Memcached API 1/2
    %{l_shtool} install -c -m 755 \
        memcache-%{V_memcache}/.libs/memcache.so \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/php-memcached/

    #   install PHP Memcached API 2/2
    %{l_shtool} install -c -m 755 \
        memcached-%{V_memcached}/.libs/memcached.so \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/php-memcached/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

%post
    if [ ".$1" = .1 ]; then
        #   add hook to PHP configuration
        phpini="$RPM_INSTALL_PREFIX/etc/php/php.ini"
        if [ -f $phpini ]; then
            ( echo "extension = $RPM_INSTALL_PREFIX/libexec/php-memcached/memcache.so"
              echo "extension = $RPM_INSTALL_PREFIX/libexec/php-memcached/memcached.so" ) |\
            $RPM_INSTALL_PREFIX/lib/openpkg/rpmtool config \
                -a -i "$RPM_INSTALL_PREFIX:php-memcached" -p ";" $phpini
        fi
%if "%{with_apache}" == "yes"
        #   add hook to Apache/PHP configuration
        phpini="$RPM_INSTALL_PREFIX/etc/apache/apache-php.ini"
        if [ -f $phpini ]; then
            ( echo "extension = $RPM_INSTALL_PREFIX/libexec/php-memcached/memcache.so"
              echo "extension = $RPM_INSTALL_PREFIX/libexec/php-memcached/memcached.so" ) |\
            $RPM_INSTALL_PREFIX/lib/openpkg/rpmtool config \
                -a -i "$RPM_INSTALL_PREFIX:php-memcached" -p ";" $phpini
        fi
%endif
    fi

%postun
    if [ ".$1" = .0 ]; then
        #   remove hook from PHP configuration
        phpini="$RPM_INSTALL_PREFIX/etc/php/php.ini"
        if [ -f $phpini ]; then
            $RPM_INSTALL_PREFIX/lib/openpkg/rpmtool config \
                -r -i "$RPM_INSTALL_PREFIX:php-memcached" -p ";" $phpini
        fi
%if "%{with_apache}" == "yes"
        #   remove hook from Apache/PHP configuration
        phpini="$RPM_INSTALL_PREFIX/etc/apache/apache-php.ini"
        if [ -f $phpini ]; then
            $RPM_INSTALL_PREFIX/lib/openpkg/rpmtool config \
                -r -i "$RPM_INSTALL_PREFIX:php-memcached" -p ";" $phpini
        fi
%endif
    fi

